# TfUtility

[![Validate](https://github.com/eieste/tfutility/actions/workflows/validate.yml/badge.svg)](https://github.com/eieste/tfutility/actions/workflows/validate.yml)


provides different tools for Terraform Developers

## Installation

```
$ pip install tfutility
```

# TF-Rule-Checker

Allows Decorator ontop of HCL/Terraform Resources to check if some things are configured correctly

## @tfmoduleupdate
## @importdate
## @moveddate
## @sourcechange
## @forcedremotesource
